/**
    ###############################################################
    Bootstrap Plus v1.0.0

    By Dylan Legendre (dylanlegendre09@gmail.com)
    http://www.dylanlegendre.com/
    Twitter: @Dylan_Legendre
    Github: http://www.github.com/MorpheusZero
    ###############################################################
 */

// Only continue if JQuery has been loaded.
if (typeof jQuery == 'undefined') {
    console.warn('Bootstrap Plus requires JQuery to be loaded!');
} else {
    
    /**
     * Creates the alertsManager div container so we can render alerts inside of it.
     */
    var createAlertsManagerContainer = function() {
        var el = document.createElement('div');
        el.id = 'alertsManager';
        el.style.display = 'inline-block';
        el.style.position = 'absolute';
        el.style.bottom = '0';
        el.style.left = '25%';
        el.style.width = '50%';
        el.style.index = '999';
        document.body.appendChild(el);
    };

    // Setting up the base ALERT HTML template that we will use to create alerts.
    var ALERT_BASE_HTML = '<div id="{:CONTAINER_ID}" class="alert alert-{:TYPE} alert-dismissible fade show" role="alert">';
    ALERT_BASE_HTML += '<strong>{:TITLE}</strong> {:MESSAGE}';
    ALERT_BASE_HTML += '<button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>';
    ALERT_BASE_HTML += '</div>';

    /**
     * Given a bootstrap TYPE and other info, will render an alert on the screen with the given options.
     * @param {string} type Any bootstrap type such as success, primary, secondary, warning, danger, etc.
     * @param {string} title A bold header for the alert.
     * @param {string} message The message that gets displayed in the alert. 
     * @param {number} delayTimeout If given, how many seconds until the alert gets auto-dismissed.
     */
    var showAlert = function(type, title, message, delayTimeout) {
        var alertID = new Date().valueOf().toString();
        var alertHTML = ALERT_BASE_HTML.replace('{:TYPE}', type).replace('{:TITLE}', title).replace('{:MESSAGE}', message).replace('{:CONTAINER_ID}', alertID);
        var alertsManager = document.getElementById('alertsManager');
        if (alertsManager) {
            var span = document.createElement('span');
            span.innerHTML = alertHTML;
            alertsManager.appendChild(span);
            if (delayTimeout) {
                // If a timeout has been provided, we should set this alert up to auto dismiss.
                setTimeout(function() {
                    var el = $('#' + alertID);
                    el.slideUp('slow', function() {
                        el.remove();
                    })
                }, delayTimeout * 1000);
            }
        } else {
            console.warn('The Alerts Manager has not been created! Cannot create an alert!');
        }
    };

    /**
     * INITIALIZATION
     */
    createAlertsManagerContainer();

    /**
     * We need to make all of this accessible to the window object for easy access.
     */
    window['BPlus'] = {
        showAlert: showAlert
    };




}